Customization
=============

.. toctree::
  :maxdepth: 2
  :hidden:

  customize_templates
  adding_pages
  customize_template_tags


Start here to learn how to customize the look and feel of your TOM or add new functionality.

:doc:`Customizing TOM Templates <customize_templates>` - Learn how to override built in TOM templates to
change the look and feel of your TOM.

:doc:`Adding new Pages to your TOM <adding_pages>` - Learn how to add entirely new pages to your TOM,
displaying static html pages or dynamic database-driven content.

:doc:`Customizing Template Tags <customize_template_tags>` - Learn how to write your own template tags to display 
the data you need.
